@@ -32,19 +32,26 @@
 #define PREF_RATE 10
 #define PREF_USER 11
 #define PREF_USER_ID 12
-#define PREF_NUM_BACKUPS 13
-#define PREF_WINDOW_WIDTH 14
-#define PREF_WINDOW_HEIGHT 15
-#define PREF_DATEBOOK_PANE 16
-#define PREF_ADDRESS_PANE 17
-#define PREF_TODO_PANE 18
-#define PREF_MEMO_PANE 19
+#define PREF_PC_ID 13
+#define PREF_NUM_BACKUPS 14
+#define PREF_WINDOW_WIDTH 15
+#define PREF_WINDOW_HEIGHT 16
+#define PREF_DATEBOOK_PANE 17
+#define PREF_ADDRESS_PANE 18
+#define PREF_TODO_PANE 19
+#define PREF_MEMO_PANE 20
+#define PREF_USE_DB3 21
+#define PREF_LAST_APP 22
+#define PREF_PRINT_THIS_MANY 23
+#define PREF_PRINT_ONE_PER_PAGE 24
+#define PREF_NUM_BLANK_LINES 25
+#define PREF_PRINT_COMMAND 26
 
-#define NUM_PREFS 20
+#define NUM_PREFS 27
 
-#define NUM_SHORTDATES  8
-#define NUM_LONGDATES  7
-#define NUM_TIMES  11
+#define NUM_SHORTDATES  7
+#define NUM_LONGDATES  6
+#define NUM_TIMES  10
 #define NUM_RATES  11
 
 #define MAX_PREF_NUM_BACKUPS 99
@@ -72,6 +79,8 @@ int write_rc_file();
 int get_pref_possibility(int which, int n, char *ret);
 int get_pref(int which, long *n, const char **ret);
 int get_pref_dmy_order();
+int get_pref_time_no_secs(char *datef);
+int get_pref_time_no_secs_no_ampm(char *datef);
 int set_pref(int which, long n);
 int set_pref_char(int which, char *string);
 /*This function is used externally to free up any memory that prefs is using */
